@@ -1,8 +1,3 @@
-format_bib = function(...) {
-  str = vapply(list(...), function(entry) tools::toRd(bibentries[[entry]]), FUN.VALUE = "")
-  paste0(str, collapse = "\n\n")
-}
-
 #' @importFrom utils bibentry
 bibentries = c(
   xiang_2013 = bibentry("article",
@@ -17,7 +12,6 @@ bibentries = c(
     doi          = "10.32614/rj-2013-002"
   ),
 
-
   tsallis_1996 = bibentry("article",
     title        = "Generalized simulated annealing",
     author       = "Constantino Tsallis and Daniel A. Stariolo",
@@ -47,5 +41,24 @@ bibentries = c(
     author       = "Johnson, Steven G",
     url          = "https://github.com/stevengj/nlopt",
     year         = "2020"
+  ),
+
+  lopez_2016 = bibentry("article",
+    title        = "The irace package: Iterated racing for automatic algorithm configuration",
+    author       = "Manuel Lopez-Ibanez and Jeremie Dubois-Lacoste and Leslie Perez Caceres and Mauro Birattari and Thomas Stuetzle",
+    year         = "2016",
+    journal      = "Operations Research Perspectives",
+    volume       = "3",
+    pages        = "43--58",
+    doi          = "https://doi.org/10.1016/j.orp.2016.09.002"
+  ),
+
+  hansen_2016 = bibentry("misc",
+    author        = "Nikolaus Hansen",
+    title         = "The CMA Evolution Strategy: A Tutorial",
+    year          = "2016",
+    eprint        = "1604.00772",
+    archivePrefix = "arXiv",
+    primaryClass  = "cs.LG"
   )
 )
