@@ -1,14 +1,14 @@
 # create a simple inst object for rpart with cp param and 2CV resampling
 TEST_MAKE_PS1 = function(n_dim = 1L) {
   if (n_dim == 1) {
-    ParamSet$new(params = list(
-      ParamDbl$new("cp", lower = 0.1, upper = 0.3)
-    ))
+    ps(
+      cp = p_dbl(lower = 0.1, upper = 0.3)
+    )
   } else if (n_dim == 2) {
-    ParamSet$new(params = list(
-      ParamDbl$new("cp", lower = 0.1, upper = 0.3),
-      ParamInt$new("minsplit", lower = 1, upper = 9)
-    ))
+    ps(
+      cp = p_dbl(lower = 0.1, upper = 0.3),
+      minsplit = p_int(lower = 1, upper = 9)
+    )
   }
 }
 TEST_MAKE_INST1 = function(values = NULL, folds = 2L,
@@ -20,7 +20,7 @@ TEST_MAKE_INST1 = function(values = NULL, folds = 2L,
   }
   rs = rsmp("cv", folds = folds)
   term = trm("evals", n_evals = term_evals)
-  inst = TuningInstanceSingleCrit$new(tsk("iris"), lrn, rs, measure, term, ps, ...)
+  inst = TuningInstanceBatchSingleCrit$new(tsk("iris"), lrn, rs, measure, term, ps, ...)
   return(inst)
 }
 
@@ -34,19 +34,17 @@ TEST_MAKE_INST1_2D = function(values = NULL, folds = 2L,
   }
   rs = rsmp("cv", folds = folds)
   term = trm("evals", n_evals = term_evals)
-  inst = TuningInstanceMultiCrit$new(tsk("iris"), lrn, rs, measures, term, ps,
+  inst = TuningInstanceBatchMultiCrit$new(tsk("iris"), lrn, rs, measures, term, ps,
     ...)
   return(inst)
 }
 
 # create inst object with dependencies
 TEST_MAKE_PS2 = function() {
-  ps = ParamSet$new(
-    params = list(
-      ParamFct$new("xx", levels = c("a", "b"), default = "a"),
-      ParamDbl$new("yy", lower = 0, upper = 1),
-      ParamDbl$new("cp", lower = 0, upper = 1)
-    )
+  ps = ps(
+    xx = p_fct(levels = c("a", "b"), default = "a"),
+    yy = p_dbl(lower = 0, upper = 1),
+    cp = p_dbl(lower = 0, upper = 1)
   )
   ps$add_dep("yy", on = "xx", cond = CondEqual$new("a"))
   return(ps)
@@ -56,7 +54,7 @@ TEST_MAKE_INST2 = function(measure = msr("dummy.cp.regr"), term_evals = 5L) {
   ll = LearnerRegrDepParams$new()
   rs = rsmp("holdout")
   term = trm("evals", n_evals = term_evals)
-  inst = TuningInstanceSingleCrit$new(tsk("boston_housing"), ll, rs, measure, term, ps)
+  inst = TuningInstanceBatchSingleCrit$new(tsk("boston_housing"), ll, rs, measure, term, ps)
   return(inst)
 }
 
@@ -141,3 +139,16 @@ MAKE_GL = function() {
   g$add_edge("subsample", "classif.rpart")
   GraphLearner$new(g)
 }
+
+flush_redis = function() {
+  config = redux::redis_config()
+  r = redux::hiredis(config)
+  r$FLUSHDB()
+}
+
+expect_rush_reset = function(rush, type = "kill") {
+  processes = rush$processes
+  rush$reset(type = type)
+  expect_list(rush$connector$command(c("KEYS", "*")), len = 0)
+  walk(processes, function(p) p$kill())
+}
